@@ -439,50 +439,6 @@ gnome_dock_item_style_set (GtkWidget *widget,
     }
 }
 
-static void
-get_handle_width_and_height(GnomeDockItem *item,
-			    int in_width, int in_height,
-			    int in_hidden_width, int in_hidden_height,
-			    int take_off_border,
-			    int *width, int *height)
-{
-  if (item->is_hidden && ! item->is_floating)
-    {
-      GtkBin *bin = GTK_BIN(item);
-      if (item->orientation == GTK_ORIENTATION_HORIZONTAL)
-        {
-          if(in_hidden_height > 0)
-	    *width = in_hidden_height;
-	  else
-	    *width = bin->child ? bin->child->allocation.height: 
-		    DRAG_HANDLE_SIZE * 3;
-          *height = DRAG_HANDLE_SIZE - take_off_border;
-        }
-      else
-        {
-          *width = DRAG_HANDLE_SIZE - take_off_border;
-          if(in_hidden_width > 0)
-            *height = in_hidden_width;
-	  else
-            *height = bin->child ? bin->child->allocation.width: 
-		  DRAG_HANDLE_SIZE * 3;
-        }
-    }
-  else
-    {
-      if (item->orientation == GTK_ORIENTATION_HORIZONTAL)
-        {
-          *height = in_height;
-          *width = DRAG_HANDLE_SIZE - take_off_border;
-        }
-      else
-        {
-          *width = in_width;
-          *height = DRAG_HANDLE_SIZE - take_off_border;
-        }
-    }
-}
-
 static void
 gnome_dock_item_size_request (GtkWidget      *widget,
                               GtkRequisition *requisition)
@@ -508,20 +464,7 @@ gnome_dock_item_size_request (GtkWidget      *widget,
       child_requisition.height = 0;
     }
 
-  if (dock_item->is_hidden)
-    {
-      int width, height;
-      get_handle_width_and_height(dock_item,
-				  child_requisition.width,
-				  child_requisition.height,
-				  child_requisition.width,
-				  child_requisition.height,
-				  GTK_CONTAINER (dock_item)->border_width * 2,
-				  &width, &height);
-      requisition->width = width;
-      requisition->height = height;
-    }
-  else if (dock_item->orientation == GTK_ORIENTATION_HORIZONTAL)
+  if (dock_item->orientation == GTK_ORIENTATION_HORIZONTAL)
     {
       requisition->width = 
         GNOME_DOCK_ITEM_NOT_LOCKED (dock_item) ? DRAG_HANDLE_SIZE : 0;
@@ -577,7 +520,7 @@ gnome_dock_item_size_allocate (GtkWidget     *widget,
     {
       GtkWidget *child;
       GtkAllocation child_allocation;
-      guint border_width;
+      int border_width;
 
       child = bin->child;
       border_width = GTK_CONTAINER (widget)->border_width;
@@ -593,33 +536,7 @@ gnome_dock_item_size_allocate (GtkWidget     *widget,
             child_allocation.y += DRAG_HANDLE_SIZE;
         }
 
-      /* When hidden, make sure the child is out of the way */
-      if (di->is_hidden)
-        {
-          GtkRequisition child_requisition;
-
-          child_allocation.x = widget->allocation.width + 1;
-          child_allocation.y = widget->allocation.height + 1;
-
-	  gtk_widget_get_child_requisition (child, &child_requisition);
-
-          child_allocation.width = child_requisition.width;
-          child_allocation.height = child_requisition.height;
-
-	  if (GTK_WIDGET_REALIZED (di))
-	    {
-	      if (di->is_floating)
-	        gdk_window_resize (di->float_window,
-				   widget->allocation.width,
-				   widget->allocation.height);
-	      gdk_window_move_resize (di->bin_window,
-				      0,
-				      0,
-				      widget->allocation.width,
-				      widget->allocation.height);
-	    }
-        }
-      else if (di->is_floating)
+      if (di->is_floating)
 	{
           GtkRequisition child_requisition;
 	  guint float_width;
@@ -652,15 +569,15 @@ gnome_dock_item_size_allocate (GtkWidget     *widget,
 	}
       else
 	{
-	  child_allocation.width = MAX (1, widget->allocation.width - 2 * border_width);
-	  child_allocation.height = MAX (1, widget->allocation.height - 2 * border_width);
+	  child_allocation.width = MAX (1, (int) widget->allocation.width - 2 * border_width);
+	  child_allocation.height = MAX (1, (int) widget->allocation.height - 2 * border_width);
 
           if (GNOME_DOCK_ITEM_NOT_LOCKED (di))
             {
               if (di->orientation == GTK_ORIENTATION_HORIZONTAL)
-		child_allocation.width = MAX((int)child_allocation.width - DRAG_HANDLE_SIZE, 1);
+		child_allocation.width = MAX ((int) child_allocation.width - DRAG_HANDLE_SIZE, 1);
               else
-		child_allocation.height = MAX(child_allocation.height - DRAG_HANDLE_SIZE, 1);
+		child_allocation.height = MAX ((int) child_allocation.height - DRAG_HANDLE_SIZE, 1);
             }
 
 	  if (GTK_WIDGET_REALIZED (di))
@@ -745,23 +662,28 @@ gnome_dock_item_paint (GtkWidget      *widget,
   if (GNOME_DOCK_ITEM_NOT_LOCKED (di))
     {
       GdkRectangle dest;
-      int w, h;
 
       rect.x = 0;
       rect.y = 0;
-
-      get_handle_width_and_height(di, width, height, 0, 0, 0, &w, &h);
-
-      rect.width = w;
-      rect.height = h;
+      
+      if (di->orientation == GTK_ORIENTATION_HORIZONTAL)
+        {
+          rect.width = DRAG_HANDLE_SIZE;
+          rect.height = height;
+        }
+      else
+        {
+          rect.width = width;
+          rect.height = DRAG_HANDLE_SIZE;
+        }
 
       if (gdk_rectangle_intersect (event ? &event->area : area, &rect, &dest))
 	draw_textured_frame (widget, di->bin_window, &rect,
-			     di->button_down ? GTK_SHADOW_IN : GTK_SHADOW_OUT,
+			     GTK_SHADOW_OUT,
 			     event ? &event->area : area);
     }    
   
-  if ( ! di->is_hidden && bin->child && GTK_WIDGET_VISIBLE (bin->child))
+  if (bin->child && GTK_WIDGET_VISIBLE (bin->child))
     {
       GdkRectangle child_area;
       GdkEventExpose child_event;
@@ -829,34 +751,13 @@ gnome_dock_item_expose (GtkWidget      *widget,
   return FALSE;
 }
 
-static void
-draw_handle(GnomeDockItem *item)
-{
-  GdkRectangle rect;
-  int width, height;
-  GtkWidget *widget = GTK_WIDGET(item);
-
-  rect.x = 0;
-  rect.y = 0;
-
-  get_handle_width_and_height(item,
-			      widget->allocation.width,
-			      widget->allocation.height,
-			      0, 0, 0,
-			      &width, &height);
-  rect.width = width;
-  rect.height = height;
-
-  gnome_dock_item_paint(widget, NULL, &rect);
-}
-
 static gint
 gnome_dock_item_button_changed (GtkWidget      *widget,
                                 GdkEventButton *event)
 {
   GnomeDockItem *di;
   gboolean event_handled;
-
+  
   g_return_val_if_fail (widget != NULL, FALSE);
   g_return_val_if_fail (GNOME_IS_DOCK_ITEM (widget), FALSE);
   g_return_val_if_fail (event != NULL, FALSE);
@@ -875,69 +776,52 @@ gnome_dock_item_button_changed (GtkWidget      *widget,
     {
       GtkWidget *child;
       gboolean in_handle;
-      int width, height;
       
       child = GTK_BIN (di)->child;
-
-      get_handle_width_and_height(di,
-				  widget->allocation.width,
-				  widget->allocation.height,
-				  0, 0, 0,
-				  &width, &height);
-      if (event->x < width && event->y < height)
-	in_handle = TRUE;
-      else
-	in_handle = FALSE;
       
+      switch (di->orientation)
+	{
+	case GTK_ORIENTATION_HORIZONTAL:
+	  in_handle = event->x < DRAG_HANDLE_SIZE;
+	  break;
+	case GTK_ORIENTATION_VERTICAL:
+	  in_handle = event->y < DRAG_HANDLE_SIZE;
+	  break;
+	default:
+	  in_handle = FALSE;
+	  break;
+	}
+
       if (!child)
 	{
 	  in_handle = FALSE;
 	  event_handled = TRUE;
 	}
-
-      di->button_down = 0;
-
+      
       if (in_handle)
 	{
-	  di->button_down = 1;
-
-	  draw_handle(di);
-
-	  /* we set these even if we weren't going to drag */
-          di->dragoff_x = event->x;
+	  di->dragoff_x = event->x;
 	  di->dragoff_y = event->y;
 
+	  di->in_drag = TRUE;
+
+          gnome_dock_item_grab_pointer (di);
+
+          gtk_signal_emit (GTK_OBJECT (widget),
+                           dock_item_signals[DOCK_DRAG_BEGIN]);
+
 	  event_handled = TRUE;
 	}
     }
-  else if (event->type == GDK_BUTTON_RELEASE)
+  else if (event->type == GDK_BUTTON_RELEASE && di->in_drag)
     {
       gdk_pointer_ungrab (GDK_CURRENT_TIME);
+      
+      di->in_drag = FALSE;
 
-      if (di->in_drag)
-	{
-          di->in_drag = FALSE;
-
-          gtk_signal_emit (GTK_OBJECT (widget),
-			   dock_item_signals[DOCK_DRAG_END]);
-          event_handled = TRUE;
-	}
-      else if (di->button_down)
-	{
-	  di->button_down = 0;
-	  di->is_hidden = !di->is_hidden;
-	  /* no need to draw the handle, queue resize will do a redraw it
-	   * for us*/
-	  gtk_widget_queue_resize(widget->parent);
-          event_handled = TRUE;
-
-	  /* XXX: A hack.  There is no signal for hiding.  This will however
-	   * signal that the layout has changed and it should be saved */
-          gtk_signal_emit (GTK_OBJECT (widget),
-			   dock_item_signals[DOCK_DRAG_BEGIN]);
-          gtk_signal_emit (GTK_OBJECT (widget),
-			   dock_item_signals[DOCK_DRAG_END]);
-	}
+      gtk_signal_emit (GTK_OBJECT (widget),
+                       dock_item_signals[DOCK_DRAG_END]);
+      event_handled = TRUE;
     }
 
   return event_handled;
@@ -955,25 +839,10 @@ gnome_dock_item_motion (GtkWidget      *widget,
   g_return_val_if_fail (event != NULL, FALSE);
 
   di = GNOME_DOCK_ITEM (widget);
-
-  if (event->window != di->bin_window)
+  if (!di->in_drag)
     return FALSE;
 
-  if (di->button_down)
-    {
-      di->button_down = 0;
-
-      di->in_drag = TRUE;
-
-      gnome_dock_item_grab_pointer (di);
-
-      gtk_signal_emit (GTK_OBJECT (widget),
-		       dock_item_signals[DOCK_DRAG_BEGIN]);
-
-      draw_handle(di);
-    }
-
-  if (!di->in_drag)
+  if (event->window != di->bin_window)
     return FALSE;
 
   gdk_window_get_pointer (NULL, &new_x, &new_y, NULL);
@@ -993,6 +862,8 @@ gnome_dock_item_add (GtkContainer *container,
                      GtkWidget    *widget)
 {
   GnomeDockItem *dock_item;
+  GtkArgInfo *info_p;
+  gchar *error;
 
   g_return_if_fail (GNOME_IS_DOCK_ITEM (container));
   g_return_if_fail (GTK_BIN (container)->child == NULL);
@@ -1003,8 +874,33 @@ gnome_dock_item_add (GtkContainer *container,
   gtk_widget_set_parent_window (widget, dock_item->bin_window);
   GTK_CONTAINER_CLASS (parent_class)->add (container, widget);
 
-  if (GTK_IS_TOOLBAR (widget))
-    gtk_toolbar_set_orientation (GTK_TOOLBAR (widget), dock_item->orientation);
+  error = gtk_object_arg_get_info (GTK_OBJECT_TYPE (widget),
+				   "orientation", &info_p);
+  if (error)
+    g_free (error);
+  else
+    gtk_object_set (GTK_OBJECT (widget),
+		    "orientation", dock_item->orientation,
+		    NULL);
+}
+
+static void
+gnome_dock_item_set_floating (GnomeDockItem *item, gboolean val)
+{
+  item->is_floating = val;
+
+  /* If there is a child and it supports the 'is_floating' flag
+   * set that too.
+   */
+  if (item->bin.child != NULL) {
+    GtkArgInfo *info_p;
+    gchar *error = gtk_object_arg_get_info (GTK_OBJECT_TYPE (item->bin.child),
+					    "is_floating", &info_p);
+    if (error)
+      g_free (error);
+    else
+      gtk_object_set (GTK_OBJECT (item->bin.child), "is_floating", val, NULL);
+  }
 }
 
 static void
@@ -1020,7 +916,7 @@ gnome_dock_item_remove (GtkContainer *container,
 
   if (di->is_floating)
     {
-      di->is_floating = FALSE;
+      gnome_dock_item_set_floating (di, FALSE);
       if (GTK_WIDGET_REALIZED (di))
 	{
 	  gdk_window_hide (di->float_window);
@@ -1180,6 +1076,9 @@ gboolean
 gnome_dock_item_set_orientation (GnomeDockItem *dock_item,
                                  GtkOrientation orientation)
 {
+  GtkArgInfo *info_p;
+  gchar *error;
+
   g_return_val_if_fail (dock_item != NULL, FALSE);
   g_return_val_if_fail (GNOME_IS_DOCK_ITEM (dock_item), FALSE);
 
@@ -1193,10 +1092,16 @@ gnome_dock_item_set_orientation (GnomeDockItem *dock_item,
 
       dock_item->orientation = orientation;
 
-      if (dock_item->bin.child != NULL
-          && GTK_IS_TOOLBAR (dock_item->bin.child))
-        gtk_toolbar_set_orientation (GTK_TOOLBAR (dock_item->bin.child),
-                                     orientation);
+      if (dock_item->bin.child != NULL) {
+	error = gtk_object_arg_get_info (GTK_OBJECT_TYPE (dock_item->bin.child),
+					 "orientation", &info_p);
+	if (error)
+	  g_free (error);
+	else
+	  gtk_object_set (GTK_OBJECT (dock_item->bin.child),
+			  "orientation", orientation,
+			  NULL);
+      }
       if (GTK_WIDGET_DRAWABLE (dock_item))
         gtk_widget_queue_clear (GTK_WIDGET (dock_item));
       gtk_widget_queue_resize (GTK_WIDGET (dock_item));
@@ -1279,7 +1184,7 @@ gnome_dock_item_detach (GnomeDockItem *item, gint x, gint y)
   item->float_x = x;
   item->float_y = y;
 
-  item->is_floating = TRUE;
+  gnome_dock_item_set_floating (item, TRUE);
 
   if (! GTK_WIDGET_REALIZED (item))
     return TRUE;
@@ -1323,7 +1228,7 @@ gnome_dock_item_attach (GnomeDockItem *item, GtkWidget *parent, gint x, gint y)
       gdk_window_show (GTK_WIDGET (item)->window);
 
       item->float_window_mapped = FALSE;
-      item->is_floating = FALSE;
+      gnome_dock_item_set_floating (item, FALSE);
 
       gtk_widget_queue_resize (GTK_WIDGET (item));
 
@@ -1357,26 +1262,10 @@ gnome_dock_item_handle_size_request (GnomeDockItem *item,
   if (bin->child != NULL)
     gtk_widget_size_request (bin->child, requisition);
 
-  if (item->is_hidden)
-    {
-      int width, height;
-      get_handle_width_and_height(item,
-				  requisition->width,
-				  requisition->height,
-				  requisition->width,
-				  requisition->height,
-				  GTK_CONTAINER (item)->border_width * 2,
-				  &width, &height);
-      requisition->width = width;
-      requisition->height = height;
-    }
+  if (item->orientation == GTK_ORIENTATION_HORIZONTAL)
+    requisition->width += DRAG_HANDLE_SIZE;
   else
-    {
-      if (item->orientation == GTK_ORIENTATION_HORIZONTAL)
-        requisition->width += DRAG_HANDLE_SIZE;
-      else
-        requisition->height += DRAG_HANDLE_SIZE;
-    }
+    requisition->height += DRAG_HANDLE_SIZE;
 
   requisition->width += container->border_width * 2;
   requisition->height += container->border_width * 2;
